@@ -17,11 +17,42 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef HS_WEBKITJAVASCRIPTCORE_H
+#define HS_WEBKITJAVASCRIPTCORE_H
+
 #ifdef __BLOCKS__
 #undef __BLOCKS__
 #endif
-#ifndef HS_WEBKITJAVASCRIPTCORE_H
-#define HS_WEBKITJAVASCRIPTCORE_H
+
+#ifdef __clang__
+#undef __clang__
+#endif
+
+#ifndef __has_builtin
+#undef __has_builtin
+#endif
+#define __has_builtin(x) 0
+#ifndef __has_include
+#undef __has_include
+#endif
+#define __has_include(x) 0
+#ifndef __has_feature
+#undef __has_feature
+#endif
+#define __has_feature(x) 0
+#ifndef __has_attribute
+#undef __has_attribute
+#endif
+#define __has_attribute(x) 0
+#ifndef __has_extension
+#undef __has_extension
+#endif
+#define __has_extension(x) 0
+
+#ifndef JSC_API_AVAILABLE
+#define JSC_API_AVAILABLE(...)
+#endif
+
 /* to avoid stdbool.h error in JavaScriptCore/JSBase.h*/
 #define _Bool unsigned char // unsigned short // previously, int
 
